==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/AutoscaleCapacityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.AutoscaleCapacityArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The load-based autoscale request parameters
 * @property maxInstanceCount The maximum instance count of the cluster
 * @property minInstanceCount The minimum instance count of the cluster
 */
public data class AutoscaleCapacityArgs(
    public val maxInstanceCount: Output<Int>? = null,
    public val minInstanceCount: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.AutoscaleCapacityArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.AutoscaleCapacityArgs =
        com.pulumi.azurenative.hdinsight.inputs.AutoscaleCapacityArgs.builder()
            .maxInstanceCount(maxInstanceCount?.applyValue({ args0 -> args0 }))
            .minInstanceCount(minInstanceCount?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AutoscaleCapacityArgs].
 */
@PulumiTagMarker
public class AutoscaleCapacityArgsBuilder internal constructor() {
    private var maxInstanceCount: Output<Int>? = null

    private var minInstanceCount: Output<Int>? = null

    /**
     * @param value The maximum instance count of the cluster
     */
    @JvmName("fmlaacfsfpfjalky")
    public suspend fun maxInstanceCount(`value`: Output<Int>) {
        this.maxInstanceCount = value
    }

    /**
     * @param value The minimum instance count of the cluster
     */
    @JvmName("mtiygnommfklqwet")
    public suspend fun minInstanceCount(`value`: Output<Int>) {
        this.minInstanceCount = value
    }

    /**
     * @param value The maximum instance count of the cluster
     */
    @JvmName("jpctcpcwxxijurtg")
    public suspend fun maxInstanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxInstanceCount = mapped
    }

    /**
     * @param value The minimum instance count of the cluster
     */
    @JvmName("baaftbedsldnmkop")
    public suspend fun minInstanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minInstanceCount = mapped
    }

    internal fun build(): AutoscaleCapacityArgs = AutoscaleCapacityArgs(
        maxInstanceCount = maxInstanceCount,
        minInstanceCount = minInstanceCount,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/AutoscaleCapacityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.AutoscaleCapacityArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The load-based autoscale request parameters
 * @property maxInstanceCount The maximum instance count of the cluster
 * @property minInstanceCount The minimum instance count of the cluster
 */
public data class AutoscaleCapacityArgs(
    public val maxInstanceCount: Output<Int>? = null,
    public val minInstanceCount: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.AutoscaleCapacityArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.AutoscaleCapacityArgs =
        com.pulumi.azurenative.hdinsight.inputs.AutoscaleCapacityArgs.builder()
            .maxInstanceCount(maxInstanceCount?.applyValue({ args0 -> args0 }))
            .minInstanceCount(minInstanceCount?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AutoscaleCapacityArgs].
 */
@PulumiTagMarker
public class AutoscaleCapacityArgsBuilder internal constructor() {
    private var maxInstanceCount: Output<Int>? = null

    private var minInstanceCount: Output<Int>? = null

    /**
     * @param value The maximum instance count of the cluster
     */
    @JvmName("lyxirqvkuusybwoc")
    public suspend fun maxInstanceCount(`value`: Output<Int>) {
        this.maxInstanceCount = value
    }

    /**
     * @param value The minimum instance count of the cluster
     */
    @JvmName("iuaxmkcglitgjoqj")
    public suspend fun minInstanceCount(`value`: Output<Int>) {
        this.minInstanceCount = value
    }

    /**
     * @param value The maximum instance count of the cluster
     */
    @JvmName("ygrhgnitiguhrwmr")
    public suspend fun maxInstanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxInstanceCount = mapped
    }

    /**
     * @param value The minimum instance count of the cluster
     */
    @JvmName("doqyjmlieyugxbbx")
    public suspend fun minInstanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minInstanceCount = mapped
    }

    internal fun build(): AutoscaleCapacityArgs = AutoscaleCapacityArgs(
        maxInstanceCount = maxInstanceCount,
        minInstanceCount = minInstanceCount,
    )
}
